@@ -22,11 +22,20 @@ class TestGetByTailNumber(object):
 		result = get_info_by_tail_number('VT-ALL')
 		assert result.__len__()>0
 
-class TestCountriesAndAirports(object):
+class TestOtherFeatures(object):
 	
 	def test_get_countries(self):
 		assert get_countries().__len__()>0
 	
 	def test_get_airports(self):
 		assert get_airports('India').__len__()>0
+
+	def test_get_airlines(self):
+		assert get_airlines().__len__()>0
+
+	def test_get_fleet(self):
+		assert get_fleet('air-india-aic').__len__()>0
+
+	def test_get_fleet(self):
+		assert get_flights('air-india-aic').__len__()>0
 	
\ No newline at end of file
